==> Stat2Data_1.6.tar.gz: Stat2Data/man/PalmBeach.Rd <==
\name{PalmBeach}
\alias{PalmBeach}
\docType{data}
\title{PalmBeach}
\description{
Votes for Geroge Bush and Pat Buchanan in Florida counties for the 2000 U.S. presidential election
}
%\useage{data(PalmBeach)}
\format{
  A dataset with 67 observations on the following 3 variables.
  \tabular{rl}{
    \code{County} \tab {Name of the Florida county}\cr
    \code{Buchanan} \tab {Number of votes for Par Buchanan}\cr
    \code{Bush} \tab {number of votes for George Bush}\cr
  }
}
\details{
The race for the presidency of the United States in the fall of 2000 was very close, with the electoral
votes from Florida determining the outcome. In the disputed final tally in Florida, George W. Bush won by just 537 votes over Al Gore,
 out of almost 6 million votes cast. About 2.3% of the votes cast in Florida
were awarded to other candidates. One of those other candidates was Pat Buchanan, who did
much better in Palm Beach County than he did anywhere else. Palm Beach County used a unique
"butterfly ballot" that had candidate names on either side of the page with "chads" to be punched
in the middle. This non-standard ballot seemed to confuse some voters, who punched votes for
Buchanan that may have been intended for a different candidate.  This dataset shows the number of votes for Bush and 
Buchanan in each Florida county. 
}
\source{
Florida county data for the 2000 presidential election can be found at
http://election.dos.state.fl.us/elections/resultsarchive/Index.asp?ElectionDate=11/7/00
}

\keyword{datasets}

==> Stat2Data_2.0.0.tar.gz: Stat2Data/man/PalmBeach.Rd <==
\name{PalmBeach}
\alias{PalmBeach}
\docType{data}
\title{Palm Beach Butterfly Ballot}
\description{
Votes for Geroge Bush and Pat Buchanan in Florida counties for the 2000 U.S. presidential election
}
\format{
  A dataset with 67 observations on the following 3 variables.
  \tabular{rl}{
    \code{County} \tab {Name of the Florida county}\cr
    \code{Buchanan} \tab {Number of votes for Pat Buchanan}\cr
    \code{Bush} \tab {Number of votes for George Bush}\cr
  }
}
\details{
The race for the presidency of the United States in the fall of 2000 was very close, with the electoral
votes from Florida determining the outcome. In the disputed final tally in Florida, George W. Bush won by just 537 votes over Al Gore,
 out of almost 6 million votes cast. About 2.3\% of the votes cast in Florida
were awarded to other candidates. One of those other candidates was Pat Buchanan, who did
much better in Palm Beach County than he did anywhere else. Palm Beach County used a unique
"butterfly ballot" that had candidate names on either side of the page with "chads" to be punched
in the middle. This non-standard ballot seemed to confuse some voters, who punched votes for
Buchanan that may have been intended for a different candidate.  This dataset shows the number of votes for Bush and
Buchanan in each Florida county.
}
\source{
Florida county data for the 2000 presidential election can be found at \cr
http://election.dos.state.fl.us/elections/resultsarchive/Index.asp?ElectionDate=11/7/00
}

\keyword{datasets}
